summaryrefslogtreecommitdiff
path: root/src/script/api/script_order.hpp
diff options
context:
space:
mode:
authorrubidium <rubidium@openttd.org>2012-03-04 16:40:06 +0000
committerrubidium <rubidium@openttd.org>2012-03-04 16:40:06 +0000
commite6a828def1b25671b4115903cb81d97c4e2348d6 (patch)
tree2940dc3adf4fef35d6e7a32540dd08b5e408a3ea /src/script/api/script_order.hpp
parent26df0fb5938733000d01b0ac263449b4a3c1371b (diff)
downloadopenttd-e6a828def1b25671b4115903cb81d97c4e2348d6.tar.xz
(svn r24006) -Fix [FS#5088]: AI used in names in API for GSOrder
Diffstat (limited to 'src/script/api/script_order.hpp')
-rw-r--r--src/script/api/script_order.hpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/script/api/script_order.hpp b/src/script/api/script_order.hpp
index eb301f50a..4a87c3748 100644
--- a/src/script/api/script_order.hpp
+++ b/src/script/api/script_order.hpp
@@ -43,45 +43,45 @@ public:
*/
enum ScriptOrderFlags {
/** Just go to the station/depot, stop unload if possible and load if needed. */
- AIOF_NONE = 0,
+ OF_NONE = 0,
/** Do not stop at the stations that are passed when going to the destination. Only for trains and road vehicles. */
- AIOF_NON_STOP_INTERMEDIATE = 1 << 0,
+ OF_NON_STOP_INTERMEDIATE = 1 << 0,
/** Do not stop at the destionation station. Only for trains and road vehicles. */
- AIOF_NON_STOP_DESTINATION = 1 << 1,
-
- /** Always unload the vehicle; only for stations. Cannot be set when AIOF_TRANSFER or AIOF_NO_UNLOAD is set. */
- AIOF_UNLOAD = 1 << 2,
- /** Transfer instead of deliver the goods; only for stations. Cannot be set when AIOF_UNLOAD or AIOF_NO_UNLOAD is set. */
- AIOF_TRANSFER = 1 << 3,
- /** Never unload the vehicle; only for stations. Cannot be set when AIOF_UNLOAD, AIOF_TRANSFER or AIOF_NO_LOAD is set. */
- AIOF_NO_UNLOAD = 1 << 4,
-
- /** Wait till the vehicle is fully loaded; only for stations. Cannot be set when AIOF_NO_LOAD is set. */
- AIOF_FULL_LOAD = 2 << 5,
- /** Wait till at least one cargo of the vehicle is fully loaded; only for stations. Cannot be set when AIOF_NO_LOAD is set. */
- AIOF_FULL_LOAD_ANY = 3 << 5,
- /** Do not load any cargo; only for stations. Cannot be set when AIOF_NO_UNLOAD, AIOF_FULL_LOAD or AIOF_FULL_LOAD_ANY is set. */
- AIOF_NO_LOAD = 1 << 7,
+ OF_NON_STOP_DESTINATION = 1 << 1,
+
+ /** Always unload the vehicle; only for stations. Cannot be set when OF_TRANSFER or OF_NO_UNLOAD is set. */
+ OF_UNLOAD = 1 << 2,
+ /** Transfer instead of deliver the goods; only for stations. Cannot be set when OF_UNLOAD or OF_NO_UNLOAD is set. */
+ OF_TRANSFER = 1 << 3,
+ /** Never unload the vehicle; only for stations. Cannot be set when OF_UNLOAD, OF_TRANSFER or OF_NO_LOAD is set. */
+ OF_NO_UNLOAD = 1 << 4,
+
+ /** Wt till the vehicle is fully loaded; only for stations. Cannot be set when OF_NO_LOAD is set. */
+ OF_FULL_LOAD = 2 << 5,
+ /** Wt till at least one cargo of the vehicle is fully loaded; only for stations. Cannot be set when OF_NO_LOAD is set. */
+ OF_FULL_LOAD_ANY = 3 << 5,
+ /** Do not load any cargo; only for stations. Cannot be set when OF_NO_UNLOAD, OF_FULL_LOAD or OF_FULL_LOAD_ANY is set. */
+ OF_NO_LOAD = 1 << 7,
/** Service the vehicle when needed, otherwise skip this order; only for depots. */
- AIOF_SERVICE_IF_NEEDED = 1 << 2,
+ OF_SERVICE_IF_NEEDED = 1 << 2,
/** Stop in the depot instead of only go there for servicing; only for depots. */
- AIOF_STOP_IN_DEPOT = 1 << 3,
+ OF_STOP_IN_DEPOT = 1 << 3,
/** Go to nearest depot. */
- AIOF_GOTO_NEAREST_DEPOT = 1 << 8,
+ OF_GOTO_NEAREST_DEPOT = 1 << 8,
/** All flags related to non-stop settings. */
- AIOF_NON_STOP_FLAGS = AIOF_NON_STOP_INTERMEDIATE | AIOF_NON_STOP_DESTINATION,
+ OF_NON_STOP_FLAGS = OF_NON_STOP_INTERMEDIATE | OF_NON_STOP_DESTINATION,
/** All flags related to unloading. */
- AIOF_UNLOAD_FLAGS = AIOF_TRANSFER | AIOF_UNLOAD | AIOF_NO_UNLOAD,
+ OF_UNLOAD_FLAGS = OF_TRANSFER | OF_UNLOAD | OF_NO_UNLOAD,
/** All flags related to loading. */
- AIOF_LOAD_FLAGS = AIOF_FULL_LOAD | AIOF_FULL_LOAD_ANY | AIOF_NO_LOAD,
+ OF_LOAD_FLAGS = OF_FULL_LOAD | OF_FULL_LOAD_ANY | OF_NO_LOAD,
/** All flags related to depots. */
- AIOF_DEPOT_FLAGS = AIOF_SERVICE_IF_NEEDED | AIOF_STOP_IN_DEPOT | AIOF_GOTO_NEAREST_DEPOT,
+ OF_DEPOT_FLAGS = OF_SERVICE_IF_NEEDED | OF_STOP_IN_DEPOT | OF_GOTO_NEAREST_DEPOT,
/** For marking invalid order flags */
- AIOF_INVALID = 0xFFFF,
+ OF_INVALID = 0xFFFF,
};
/**